Initialize a new Azure Data Lake Gen2 Datastore.
register_azure_data_lake_gen2_datastore(
workspace,
datastore_name,
filesystem,
account_name,
tenant_id,
client_id,
client_secret,
resource_url = NULL,
authority_url = NULL,
protocol = NULL,
endpoint = NULL,
overwrite = FALSE
)The workspace this datastore belongs to.
The datastore name.
The name of the Data Lake Gen2 filesystem.
The storage account name.
The Directory ID/Tenant ID of the service principal.
The Client ID/Application ID of the service principal.
The secret of the service principal.
The resource URL, which determines what operations will be performed on the data lake store, defaults to https://storage.azure.com/ which allows us to perform filesystem operations.
The authority URL used to authenticate the user, defaults to "https://login.microsoftonline.com".
Protocol to use to connect to the blob container. If None, defaults to "https".
The endpoint of the blob container. If None, defaults to "core.windows.net".
Whether to overwrite an existing datastore. If the datastore does not exist, it will create one. The default is FALSE.
The azureml.data.azure_data_lake_datastore.AzureDataLakeGen2Datastore
object.
# Create and register an Azure Data Lake Gen2 Datastore to a workspace.my_adlsgen2_ds <- register_azure_data_lake_gen2_datastore(workspace = your_workspace, datastore_name = <name for this datastore>, filesystem = 'test', tenant_id = your_workspace$auth$tenant_id, client_id = your_workspace$auth$service_principal_id, client_secret = your_workspace$auth$service_principal_password)