Register the Dataset in the workspace, making it available to other users of the workspace.
register_dataset(
workspace,
dataset,
name,
description = NULL,
tags = NULL,
create_new_version = FALSE
)The AzureML workspace in which the Dataset is to be registered.
The dataset to be registered.
The name of the Dataset in the workspace.
A description of the Dataset.
Named list of tags to give the Dataset. Defaults to NULL.
Boolean to register the dataset as a new version under the specified name.
The registered Dataset object.