Learn R Programming

azuremlsdk (version 1.10.0)

register_do_azureml_parallel: Registers AMLCompute as a parallel backend with the foreach package.

Description

Registers AMLCompute as a parallel backend with the foreach package.

Usage

register_do_azureml_parallel(workspace, compute_target)

Arguments

workspace

The Workspace object which has the compute_target.

compute_target

The AMLCompute target to use for parallelization.